[Freeswitch-svn] [commit] r8263 - in freeswitch/trunk/src: . include mod/applications/mod_conference mod/applications/mod_dptools mod/applications/mod_fifo mod/applications/mod_limit mod/endpoints/mod_alsa mod/endpoints/mod_dingaling mod/endpoints/mod_iax mod/endpoints/mod_portaudio mod/endpoints/mod_reference mod/endpoints/mod_sofia mod/endpoints/mod_wanpipe mod/endpoints/mod_wanpipe/libsangoma mod/endpoints/mod_woomera mod/event_handlers/mod_cdr_csv mod/event_handlers/mod_radius_cdr mod/languages/mod_lua mod/languages/mod_perl mod/languages/mod_python mod/languages/mod_spidermonkey mod/xml_int/mod_xml_cdr

Freeswitch SVN anthm at freeswitch.org
Mon May 5 11:30:56 EDT 2008


Author: anthm
Date: Mon May  5 11:30:55 2008
New Revision: 8263

Modified:
   freeswitch/trunk/src/include/switch_module_interfaces.h
   freeswitch/trunk/src/include/switch_types.h
   freeswitch/trunk/src/mod/applications/mod_conference/mod_conference.c
   freeswitch/trunk/src/mod/applications/mod_dptools/mod_dptools.c
   freeswitch/trunk/src/mod/applications/mod_fifo/mod_fifo.c
   freeswitch/trunk/src/mod/applications/mod_limit/mod_limit.c
   freeswitch/trunk/src/mod/endpoints/mod_alsa/mod_alsa.c
   freeswitch/trunk/src/mod/endpoints/mod_dingaling/mod_dingaling.c
   freeswitch/trunk/src/mod/endpoints/mod_iax/mod_iax.c
   freeswitch/trunk/src/mod/endpoints/mod_portaudio/mod_portaudio.c
   freeswitch/trunk/src/mod/endpoints/mod_reference/mod_reference.c
   freeswitch/trunk/src/mod/endpoints/mod_sofia/mod_sofia.c
   freeswitch/trunk/src/mod/endpoints/mod_sofia/sofia_presence.c
   freeswitch/trunk/src/mod/endpoints/mod_wanpipe/libsangoma/sangoma_pri.c
   freeswitch/trunk/src/mod/endpoints/mod_wanpipe/mod_wanpipe.c
   freeswitch/trunk/src/mod/endpoints/mod_woomera/mod_woomera.c
   freeswitch/trunk/src/mod/event_handlers/mod_cdr_csv/mod_cdr_csv.c
   freeswitch/trunk/src/mod/event_handlers/mod_radius_cdr/mod_radius_cdr.c
   freeswitch/trunk/src/mod/languages/mod_lua/freeswitch_lua.cpp
   freeswitch/trunk/src/mod/languages/mod_perl/freeswitch_perl.cpp
   freeswitch/trunk/src/mod/languages/mod_python/switch_swig_wrap.c
   freeswitch/trunk/src/mod/languages/mod_spidermonkey/mod_spidermonkey.c
   freeswitch/trunk/src/mod/xml_int/mod_xml_cdr/mod_xml_cdr.c
   freeswitch/trunk/src/switch_channel.c
   freeswitch/trunk/src/switch_core_sqldb.c
   freeswitch/trunk/src/switch_core_state_machine.c
   freeswitch/trunk/src/switch_cpp.cpp
   freeswitch/trunk/src/switch_ivr.c
   freeswitch/trunk/src/switch_ivr_bridge.c
   freeswitch/trunk/src/switch_ivr_originate.c

Log:
change names to protect the innocent

Modified: freeswitch/trunk/src/include/switch_module_interfaces.h
==============================================================================
--- freeswitch/trunk/src/include/switch_module_interfaces.h	(original)
+++ freeswitch/trunk/src/include/switch_module_interfaces.h	Mon May  5 11:30:55 2008
@@ -63,17 +63,17 @@
 	/*! executed when the state changes to init */
 	switch_state_handler_t on_init;
 	/*! executed when the state changes to ring */
-	switch_state_handler_t on_ring;
+	switch_state_handler_t on_routing;
 	/*! executed when the state changes to execute */
 	switch_state_handler_t on_execute;
 	/*! executed when the state changes to hangup */
 	switch_state_handler_t on_hangup;
 	/*! executed when the state changes to loopback */
-	switch_state_handler_t on_loopback;
+	switch_state_handler_t on_exchange_media;
 	/*! executed when the state changes to transmit */
-	switch_state_handler_t on_transmit;
+	switch_state_handler_t on_soft_execute;
 	/*! executed when the state changes to hold */
-	switch_state_handler_t on_hold;
+	switch_state_handler_t on_consume_media;
 	/*! executed when the state changes to hibernate */
 	switch_state_handler_t on_hibernate;
 	/*! executed when the state changes to reset */

Modified: freeswitch/trunk/src/include/switch_types.h
==============================================================================
--- freeswitch/trunk/src/include/switch_types.h	(original)
+++ freeswitch/trunk/src/include/switch_types.h	Mon May  5 11:30:55 2008
@@ -628,16 +628,16 @@
 
 /*!
   \enum switch_channel_state_t
-  \brief Channel States
+  \brief Channel States (these are the defaults, CS_SOFT_EXECUTE, CS_EXCHANGE_MEDIA, and CS_CONSUME_MEDIA are often overridden by specific apps)
 <pre>
 CS_NEW       - Channel is newly created 
 CS_INIT      - Channel has been initilized
-CS_RING      - Channel is looking for a dialplan
-CS_TRANSMIT  - Channel is in a passive transmit state
+CS_ROUTING   - Channel is looking for an extension to execute
+CS_SOFT_EXECUTE  - Channel is ready to execute from 3rd party control
 CS_EXECUTE   - Channel is executing it's dialplan 
-CS_LOOPBACK  - Channel is in loopback
-CS_PARK      - Channel is parked
-CS_HOLD		 - Channel is on hold
+CS_EXCHANGE_MEDIA  - Channel is exchanging media with another channel.
+CS_PARK      - Channel is accepting media awaiting commands.
+CS_CONSUME_MEDIA		 - Channel is consuming all media and dropping it.
 CS_HIBERNATE - Channel is in a sleep state
 CS_RESET 	 - Channel is in a reset state
 CS_HANGUP    - Channel is flagged for hangup and ready to end
@@ -647,12 +647,12 @@
 typedef enum {
 	CS_NEW,
 	CS_INIT,
-	CS_RING,
-	CS_TRANSMIT,
+	CS_ROUTING,
+	CS_SOFT_EXECUTE,
 	CS_EXECUTE,
-	CS_LOOPBACK,
+	CS_EXCHANGE_MEDIA,
 	CS_PARK,
-	CS_HOLD,
+	CS_CONSUME_MEDIA,
 	CS_HIBERNATE,
 	CS_RESET,
 	CS_HANGUP,

Modified: freeswitch/trunk/src/mod/applications/mod_conference/mod_conference.c
==============================================================================
--- freeswitch/trunk/src/mod/applications/mod_conference/mod_conference.c	(original)
+++ freeswitch/trunk/src/mod/applications/mod_conference/mod_conference.c	Mon May  5 11:30:55 2008
@@ -348,7 +348,7 @@
 static switch_status_t conference_say(conference_obj_t * conference, const char *text, uint32_t leadin);
 static void conference_list(conference_obj_t * conference, switch_stream_handle_t *stream, char *delim);
 SWITCH_STANDARD_API(conf_api_main);
-static switch_status_t audio_bridge_on_ring(switch_core_session_t *session);
+static switch_status_t audio_bridge_on_routing(switch_core_session_t *session);
 static switch_status_t conference_outcall(conference_obj_t * conference,
 										  char *conference_name,
 										  switch_core_session_t *session,
@@ -581,7 +581,7 @@
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "alt_event_type", "dialog");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "event_count", "%d", EC++);
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "unique-id", "%s", conference->name);
-			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_RING");
+			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_ROUTING");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "answer-state", "%s", conference->count == 1 ? "early" : "confirmed");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "call-direction", "%s", conference->count == 1 ? "outbound" : "inbound");
 			switch_event_fire(&event);
@@ -723,7 +723,7 @@
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "alt_event_type", "dialog");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "event_count", "%d", EC++);
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "unique-id", "%s", conference->name);
-			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_RING");
+			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_ROUTING");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "answer-state", "%s", conference->count == 1 ? "early" : "confirmed");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "call-direction", "%s", conference->count == 1 ? "outbound" : "inbound");
 			switch_event_fire(&event);
@@ -3726,7 +3726,7 @@
 }
 
 /* outbound call bridge progress call state callback handler */
-static switch_status_t audio_bridge_on_ring(switch_core_session_t *session)
+static switch_status_t audio_bridge_on_routing(switch_core_session_t *session)
 {
 	switch_channel_t *channel = NULL;
 
@@ -3735,18 +3735,18 @@
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CUSTOM RING\n");
 
 	/* put the channel in a passive state so we can loop audio to it */
-	switch_channel_set_state(channel, CS_TRANSMIT);
+	switch_channel_set_state(channel, CS_SOFT_EXECUTE);
 	return SWITCH_STATUS_FALSE;
 }
 
 static switch_state_handler_table_t audio_bridge_peer_state_handlers = {
 	/*.on_init */ NULL,
-	/*.on_ring */ audio_bridge_on_ring,
+	/*.on_routing */ audio_bridge_on_routing,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ NULL,
-	/*.on_loopback */ NULL,
-	/*.on_transmit */ NULL,
-	/*.on_hold */ NULL,
+	/*.on_exchange_media */ NULL,
+	/*.on_soft_execute */ NULL,
+	/*.on_consume_media */ NULL,
 };
 
 
@@ -5124,7 +5124,7 @@
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "alt_event_type", "dialog");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "event_count", "%d", EC++);
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "unique-id", "%s", conf_name);
-			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_RING");
+			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_ROUTING");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "answer-state", "%s", conference->count == 1 ? "early" : "confirmed");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "call-direction", "%s", conference->count == 1 ? "outbound" : "inbound");
 			switch_event_fire(&event);

Modified: freeswitch/trunk/src/mod/applications/mod_dptools/mod_dptools.c
==============================================================================
--- freeswitch/trunk/src/mod/applications/mod_dptools/mod_dptools.c	(original)
+++ freeswitch/trunk/src/mod/applications/mod_dptools/mod_dptools.c	Mon May  5 11:30:55 2008
@@ -1341,7 +1341,7 @@
 	switch_channel_state_t state = switch_channel_get_state(channel);
 	const char *id = NULL;
 
-	if (state == CS_HANGUP || state == CS_RING) {
+	if (state == CS_HANGUP || state == CS_ROUTING) {
 		if ((id = switch_channel_get_variable(channel, "xfer_uuids"))) {
 			switch_stream_handle_t stream = { 0 };
 			SWITCH_STANDARD_STREAM(stream);
@@ -1703,7 +1703,7 @@
 			}
 
 		}
-		if (!switch_channel_test_flag(caller_channel, CF_TRANSFER) && switch_channel_get_state(caller_channel) != CS_RING) {
+		if (!switch_channel_test_flag(caller_channel, CF_TRANSFER) && switch_channel_get_state(caller_channel) != CS_ROUTING) {
 			switch_channel_hangup(caller_channel, cause);
 		}
 		return;

Modified: freeswitch/trunk/src/mod/applications/mod_fifo/mod_fifo.c
==============================================================================
--- freeswitch/trunk/src/mod/applications/mod_fifo/mod_fifo.c	(original)
+++ freeswitch/trunk/src/mod/applications/mod_fifo/mod_fifo.c	Mon May  5 11:30:55 2008
@@ -294,7 +294,7 @@
 		switch_event_add_header(event, SWITCH_STACK_BOTTOM, "alt_event_type", "dialog");
 		switch_event_add_header(event, SWITCH_STACK_BOTTOM, "event_count", "%d", 0);
 
-        switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", wait_count > 0 ? "CS_RING" : "CS_HANGUP");
+        switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", wait_count > 0 ? "CS_ROUTING" : "CS_HANGUP");
         switch_event_add_header(event, SWITCH_STACK_BOTTOM, "unique-id", "%s", node->name);
         switch_event_add_header(event, SWITCH_STACK_BOTTOM, "answer-state", "%s", wait_count > 0 ? "early" : "terminated");
         switch_event_add_header(event, SWITCH_STACK_BOTTOM, "call-direction", "%s", "inbound");

Modified: freeswitch/trunk/src/mod/applications/mod_limit/mod_limit.c
==============================================================================
--- freeswitch/trunk/src/mod/applications/mod_limit/mod_limit.c	(original)
+++ freeswitch/trunk/src/mod/applications/mod_limit/mod_limit.c	Mon May  5 11:30:55 2008
@@ -281,7 +281,7 @@
 	const char *id = NULL;
 	char *sql = NULL;
 
-	if (state == CS_HANGUP || state == CS_RING) {
+	if (state == CS_HANGUP || state == CS_ROUTING) {
 		id = switch_channel_get_variable(channel, "limit_id");
 		realm = switch_channel_get_variable(channel, "limit_realm");
 		sql = switch_mprintf("delete from limit_data where uuid='%q' and hostname='%q' and realm='%q'and id='%q';", 

Modified: freeswitch/trunk/src/mod/endpoints/mod_alsa/mod_alsa.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_alsa/mod_alsa.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_alsa/mod_alsa.c	Mon May  5 11:30:55 2008
@@ -143,9 +143,9 @@
 static void remove_pvt(private_t * tech_pvt);
 static switch_status_t channel_on_init(switch_core_session_t *session);
 static switch_status_t channel_on_hangup(switch_core_session_t *session);
-static switch_status_t channel_on_ring(switch_core_session_t *session);
-static switch_status_t channel_on_loopback(switch_core_session_t *session);
-static switch_status_t channel_on_transmit(switch_core_session_t *session);
+static switch_status_t channel_on_routing(switch_core_session_t *session);
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session);
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session);
 static switch_call_cause_t channel_outgoing_channel(switch_core_session_t *session,
 													switch_caller_profile_t *outbound_profile,
 													switch_core_session_t **new_session, switch_memory_pool_t **pool, switch_originate_flag_t flags);
@@ -294,13 +294,13 @@
 	switch_set_flag_locked(tech_pvt, TFLAG_IO);
 
 	/* Move Channel's State Machine to RING */
-	switch_channel_set_state(channel, CS_RING);
+	switch_channel_set_state(channel, CS_ROUTING);
 
 	return SWITCH_STATUS_SUCCESS;
 
 }
 
-static switch_status_t channel_on_ring(switch_core_session_t *session)
+static switch_status_t channel_on_routing(switch_core_session_t *session)
 {
 	switch_channel_t *channel = NULL;
 	private_t *tech_pvt = NULL;
@@ -478,13 +478,13 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_transmit(switch_core_session_t *session)
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL TRANSMIT\n");
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_loopback(switch_core_session_t *session)
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session)
 {
 	switch_channel_t *channel = NULL;
 	private_t *tech_pvt = NULL;
@@ -737,11 +737,11 @@
 
 static switch_state_handler_table_t channel_event_handlers = {
 	/*.on_init */ channel_on_init,
-	/*.on_ring */ channel_on_ring,
+	/*.on_routing */ channel_on_routing,
 	/*.on_execute */ channel_on_execute,
 	/*.on_hangup */ channel_on_hangup,
-	/*.on_loopback */ channel_on_loopback,
-	/*.on_transmit */ channel_on_transmit
+	/*.on_exchange_media */ channel_on_exchange_media,
+	/*.on_soft_execute */ channel_on_soft_execute
 };
 
 static switch_io_routines_t channel_io_routines = {

Modified: freeswitch/trunk/src/mod/endpoints/mod_dingaling/mod_dingaling.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_dingaling/mod_dingaling.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_dingaling/mod_dingaling.c	Mon May  5 11:30:55 2008
@@ -205,9 +205,9 @@
 SWITCH_STANDARD_API(dl_debug);
 static switch_status_t channel_on_init(switch_core_session_t *session);
 static switch_status_t channel_on_hangup(switch_core_session_t *session);
-static switch_status_t channel_on_ring(switch_core_session_t *session);
-static switch_status_t channel_on_loopback(switch_core_session_t *session);
-static switch_status_t channel_on_transmit(switch_core_session_t *session);
+static switch_status_t channel_on_routing(switch_core_session_t *session);
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session);
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session);
 static switch_call_cause_t channel_outgoing_channel(switch_core_session_t *session,
 													switch_caller_profile_t *outbound_profile,
 													switch_core_session_t **new_session, switch_memory_pool_t **pool, switch_originate_flag_t flags);
@@ -1166,13 +1166,13 @@
 
 	if (negotiate_media(session) == SWITCH_STATUS_SUCCESS) {
 		/* Move Channel's State Machine to RING */
-		switch_channel_set_state(channel, CS_RING);
+		switch_channel_set_state(channel, CS_ROUTING);
 	}
 
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_ring(switch_core_session_t *session)
+static switch_status_t channel_on_routing(switch_core_session_t *session)
 {
 	switch_channel_t *channel = switch_core_session_get_channel(session);
 	struct private_object *tech_pvt = NULL;
@@ -1294,13 +1294,13 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_loopback(switch_core_session_t *session)
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL LOOPBACK\n");
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_transmit(switch_core_session_t *session)
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL TRANSMIT\n");
 	return SWITCH_STATUS_SUCCESS;
@@ -1564,11 +1564,11 @@
 
 switch_state_handler_table_t dingaling_event_handlers = {
 	/*.on_init */ channel_on_init,
-	/*.on_ring */ channel_on_ring,
+	/*.on_routing */ channel_on_routing,
 	/*.on_execute */ channel_on_execute,
 	/*.on_hangup */ channel_on_hangup,
-	/*.on_loopback */ channel_on_loopback,
-	/*.on_transmit */ channel_on_transmit
+	/*.on_exchange_media */ channel_on_exchange_media,
+	/*.on_soft_execute */ channel_on_soft_execute
 };
 
 switch_io_routines_t dingaling_io_routines = {

Modified: freeswitch/trunk/src/mod/endpoints/mod_iax/mod_iax.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_iax/mod_iax.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_iax/mod_iax.c	Mon May  5 11:30:55 2008
@@ -416,9 +416,9 @@
 
 static switch_status_t channel_on_init(switch_core_session_t *session);
 static switch_status_t channel_on_hangup(switch_core_session_t *session);
-static switch_status_t channel_on_ring(switch_core_session_t *session);
-static switch_status_t channel_on_loopback(switch_core_session_t *session);
-static switch_status_t channel_on_transmit(switch_core_session_t *session);
+static switch_status_t channel_on_routing(switch_core_session_t *session);
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session);
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session);
 static switch_call_cause_t channel_outgoing_channel(switch_core_session_t *session,
 													switch_caller_profile_t *outbound_profile,
 													switch_core_session_t **new_session, switch_memory_pool_t **pool, switch_originate_flag_t flags);
@@ -468,7 +468,7 @@
 	switch_set_flag_locked(tech_pvt, TFLAG_IO);
 
 	/* Move Channel's State Machine to RING */
-	switch_channel_set_state(switch_core_session_get_channel(session), CS_RING);
+	switch_channel_set_state(switch_core_session_get_channel(session), CS_ROUTING);
 	switch_mutex_lock(globals.mutex);
 	globals.calls++;
 	switch_mutex_unlock(globals.mutex);
@@ -476,7 +476,7 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_ring(switch_core_session_t *session)
+static switch_status_t channel_on_routing(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "%s CHANNEL RING\n", switch_channel_get_name(switch_core_session_get_channel(session)));
 	return SWITCH_STATUS_SUCCESS;
@@ -545,13 +545,13 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_loopback(switch_core_session_t *session)
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL LOOPBACK\n");
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_transmit(switch_core_session_t *session)
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL TRANSMIT\n");
 	return SWITCH_STATUS_SUCCESS;
@@ -800,11 +800,11 @@
 
 switch_state_handler_table_t iax_state_handlers = {
 	/*.on_init */ channel_on_init,
-	/*.on_ring */ channel_on_ring,
+	/*.on_routing */ channel_on_routing,
 	/*.on_execute */ channel_on_execute,
 	/*.on_hangup */ channel_on_hangup,
-	/*.on_loopback */ channel_on_loopback,
-	/*.on_transmit */ channel_on_transmit
+	/*.on_exchange_media */ channel_on_exchange_media,
+	/*.on_soft_execute */ channel_on_soft_execute
 };
 
 switch_io_routines_t iax_io_routines = {

Modified: freeswitch/trunk/src/mod/endpoints/mod_portaudio/mod_portaudio.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_portaudio/mod_portaudio.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_portaudio/mod_portaudio.c	Mon May  5 11:30:55 2008
@@ -140,9 +140,9 @@
 static void remove_pvt(private_t * tech_pvt);
 static switch_status_t channel_on_init(switch_core_session_t *session);
 static switch_status_t channel_on_hangup(switch_core_session_t *session);
-static switch_status_t channel_on_ring(switch_core_session_t *session);
-static switch_status_t channel_on_loopback(switch_core_session_t *session);
-static switch_status_t channel_on_transmit(switch_core_session_t *session);
+static switch_status_t channel_on_routing(switch_core_session_t *session);
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session);
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session);
 static switch_call_cause_t channel_outgoing_channel(switch_core_session_t *session,
 													switch_caller_profile_t *outbound_profile,
 													switch_core_session_t **new_session, switch_memory_pool_t **pool, switch_originate_flag_t flags);
@@ -284,12 +284,12 @@
 	switch_set_flag_locked(tech_pvt, TFLAG_IO);
 
 	/* Move Channel's State Machine to RING */
-	switch_channel_set_state(channel, CS_RING);
+	switch_channel_set_state(channel, CS_ROUTING);
 
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_ring(switch_core_session_t *session)
+static switch_status_t channel_on_routing(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "%s CHANNEL RING\n", switch_channel_get_name(switch_core_session_get_channel(session)));
 	return SWITCH_STATUS_SUCCESS;
@@ -435,13 +435,13 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_transmit(switch_core_session_t *session)
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL TRANSMIT\n");
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_loopback(switch_core_session_t *session)
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL LOOPBACK\n");
 	return SWITCH_STATUS_SUCCESS;
@@ -622,11 +622,11 @@
 
 switch_state_handler_table_t portaudio_event_handlers = {
 	/*.on_init */ channel_on_init,
-	/*.on_ring */ channel_on_ring,
+	/*.on_routing */ channel_on_routing,
 	/*.on_execute */ channel_on_execute,
 	/*.on_hangup */ channel_on_hangup,
-	/*.on_loopback */ channel_on_loopback,
-	/*.on_transmit */ channel_on_transmit
+	/*.on_exchange_media */ channel_on_exchange_media,
+	/*.on_soft_execute */ channel_on_soft_execute
 };
 
 switch_io_routines_t portaudio_io_routines = {

Modified: freeswitch/trunk/src/mod/endpoints/mod_reference/mod_reference.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_reference/mod_reference.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_reference/mod_reference.c	Mon May  5 11:30:55 2008
@@ -100,9 +100,9 @@
 
 static switch_status_t channel_on_init(switch_core_session_t *session);
 static switch_status_t channel_on_hangup(switch_core_session_t *session);
-static switch_status_t channel_on_ring(switch_core_session_t *session);
-static switch_status_t channel_on_loopback(switch_core_session_t *session);
-static switch_status_t channel_on_transmit(switch_core_session_t *session);
+static switch_status_t channel_on_routing(switch_core_session_t *session);
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session);
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session);
 static switch_call_cause_t channel_outgoing_channel(switch_core_session_t *session,
 													switch_caller_profile_t *outbound_profile,
 													switch_core_session_t **new_session, switch_memory_pool_t **pool, switch_originate_flag_t flags);
@@ -140,7 +140,7 @@
 	switch_set_flag_locked(tech_pvt, TFLAG_IO);
 
 	/* Move Channel's State Machine to RING */
-	switch_channel_set_state(channel, CS_RING);
+	switch_channel_set_state(channel, CS_ROUTING);
 	switch_mutex_lock(globals.mutex);
 	globals.calls++;
 	switch_mutex_unlock(globals.mutex);
@@ -148,7 +148,7 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_ring(switch_core_session_t *session)
+static switch_status_t channel_on_routing(switch_core_session_t *session)
 {
 	switch_channel_t *channel = NULL;
 	private_t *tech_pvt = NULL;
@@ -245,13 +245,13 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_loopback(switch_core_session_t *session)
+static switch_status_t channel_on_exchange_media(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL LOOPBACK\n");
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t channel_on_transmit(switch_core_session_t *session)
+static switch_status_t channel_on_soft_execute(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "CHANNEL TRANSMIT\n");
 	return SWITCH_STATUS_SUCCESS;
@@ -479,11 +479,11 @@
 
 switch_state_handler_table_t reference_state_handlers = {
 	/*.on_init */ channel_on_init,
-	/*.on_ring */ channel_on_ring,
+	/*.on_routing */ channel_on_routing,
 	/*.on_execute */ channel_on_execute,
 	/*.on_hangup */ channel_on_hangup,
-	/*.on_loopback */ channel_on_loopback,
-	/*.on_transmit */ channel_on_transmit
+	/*.on_exchange_media */ channel_on_exchange_media,
+	/*.on_soft_execute */ channel_on_soft_execute
 };
 
 switch_io_routines_t reference_io_routines = {

Modified: freeswitch/trunk/src/mod/endpoints/mod_sofia/mod_sofia.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_sofia/mod_sofia.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_sofia/mod_sofia.c	Mon May  5 11:30:55 2008
@@ -50,8 +50,8 @@
 
 static switch_status_t sofia_on_init(switch_core_session_t *session);
 
-static switch_status_t sofia_on_loopback(switch_core_session_t *session);
-static switch_status_t sofia_on_transmit(switch_core_session_t *session);
+static switch_status_t sofia_on_exchange_media(switch_core_session_t *session);
+static switch_status_t sofia_on_soft_execute(switch_core_session_t *session);
 static switch_call_cause_t sofia_outgoing_channel(switch_core_session_t *session,
 												  switch_caller_profile_t *outbound_profile, switch_core_session_t **new_session,
 												  switch_memory_pool_t **pool, switch_originate_flag_t flags);
@@ -104,12 +104,12 @@
 	}
 
 	/* Move Channel's State Machine to RING */
-	switch_channel_set_state(channel, CS_RING);
+	switch_channel_set_state(channel, CS_ROUTING);
 	assert( switch_channel_get_state(channel) != CS_INIT);
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t sofia_on_ring(switch_core_session_t *session)
+static switch_status_t sofia_on_routing(switch_core_session_t *session)
 {
 	private_object_t *tech_pvt = (private_object_t *) switch_core_session_get_private(session);
 	switch_assert(tech_pvt != NULL);
@@ -316,13 +316,13 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t sofia_on_loopback(switch_core_session_t *session)
+static switch_status_t sofia_on_exchange_media(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "SOFIA LOOPBACK\n");
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t sofia_on_transmit(switch_core_session_t *session)
+static switch_status_t sofia_on_soft_execute(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "SOFIA TRANSMIT\n");
 	return SWITCH_STATUS_SUCCESS;
@@ -1635,12 +1635,12 @@
 
 switch_state_handler_table_t sofia_event_handlers = {
 	/*.on_init */ sofia_on_init,
-	/*.on_ring */ sofia_on_ring,
+	/*.on_routing */ sofia_on_routing,
 	/*.on_execute */ sofia_on_execute,
 	/*.on_hangup */ sofia_on_hangup,
-	/*.on_loopback */ sofia_on_loopback,
-	/*.on_transmit */ sofia_on_transmit,
-	/*.on_hold */ NULL,
+	/*.on_exchange_media */ sofia_on_exchange_media,
+	/*.on_soft_execute */ sofia_on_soft_execute,
+	/*.on_consume_media */ NULL,
 	/*.on_hibernate*/ sofia_on_hibernate,
 	/*.on_reset*/ sofia_on_reset
 };

Modified: freeswitch/trunk/src/mod/endpoints/mod_sofia/sofia_presence.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_sofia/sofia_presence.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_sofia/sofia_presence.c	Mon May  5 11:30:55 2008
@@ -701,7 +701,7 @@
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_HANGUP");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "answer-state", "%s", "resubscribe");
 		} else {
-			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_RING");
+			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "channel-state", "%s", "CS_ROUTING");
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "unique-id", "%s", uuid);
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "answer-state", "%s", state);
 			switch_event_add_header(event, SWITCH_STACK_BOTTOM, "astate", "%s", state);

Modified: freeswitch/trunk/src/mod/endpoints/mod_wanpipe/libsangoma/sangoma_pri.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_wanpipe/libsangoma/sangoma_pri.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_wanpipe/libsangoma/sangoma_pri.c	Mon May  5 11:30:55 2008
@@ -52,7 +52,7 @@
 	{2, SANGOMA_PRI_EVENT_DCHAN_DOWN, "DCHAN_DOWN"},
 	{3, SANGOMA_PRI_EVENT_RESTART, "RESTART"},
 	{4, SANGOMA_PRI_EVENT_CONFIG_ERR, "CONFIG_ERR"},
-	{5, SANGOMA_PRI_EVENT_RING, "RING"},
+	{5, SANGOMA_PRI_EVENT_RING, "ROUTING"},
 	{6, SANGOMA_PRI_EVENT_HANGUP, "HANGUP"},
 	{7, SANGOMA_PRI_EVENT_RINGING, "RINGING"},
 	{8, SANGOMA_PRI_EVENT_ANSWER, "ANSWER"},

Modified: freeswitch/trunk/src/mod/endpoints/mod_wanpipe/mod_wanpipe.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_wanpipe/mod_wanpipe.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_wanpipe/mod_wanpipe.c	Mon May  5 11:30:55 2008
@@ -464,8 +464,8 @@
 static int str2switch(char *swtype);
 static switch_status_t wanpipe_on_init(switch_core_session_t *session);
 static switch_status_t wanpipe_on_hangup(switch_core_session_t *session);
-static switch_status_t wanpipe_on_loopback(switch_core_session_t *session);
-static switch_status_t wanpipe_on_transmit(switch_core_session_t *session);
+static switch_status_t wanpipe_on_exchange_media(switch_core_session_t *session);
+static switch_status_t wanpipe_on_soft_execute(switch_core_session_t *session);
 static switch_call_cause_t wanpipe_outgoing_channel(switch_core_session_t *session, switch_caller_profile_t *outbound_profile,
 													switch_core_session_t **new_session, switch_memory_pool_t **pool, switch_originate_flag_t flags);
 static switch_status_t wanpipe_read_frame(switch_core_session_t *session, switch_frame_t **frame, int timeout,
@@ -474,7 +474,7 @@
 										 switch_io_flag_t flags, int stream_id);
 static int on_info(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent);
 static int on_hangup(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent);
-static int on_ring(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent);
+static int on_routing(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent);
 static int check_flags(struct sangoma_pri *spri);
 static int on_restart(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent);
 static int on_anything(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent);
@@ -614,11 +614,11 @@
  done:
 
 	/* Move Channel's State Machine to RING */
-	switch_channel_set_state(channel, CS_RING);
+	switch_channel_set_state(channel, CS_ROUTING);
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t wanpipe_on_ring(switch_core_session_t *session)
+static switch_status_t wanpipe_on_routing(switch_core_session_t *session)
 {
 	switch_channel_t *channel = NULL;
 	private_object_t *tech_pvt = NULL;
@@ -694,13 +694,13 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t wanpipe_on_loopback(switch_core_session_t *session)
+static switch_status_t wanpipe_on_exchange_media(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "WANPIPE LOOPBACK\n");
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t wanpipe_on_transmit(switch_core_session_t *session)
+static switch_status_t wanpipe_on_soft_execute(switch_core_session_t *session)
 {
 	private_object_t *tech_pvt;
 	switch_channel_t *channel;
@@ -1001,11 +1001,11 @@
 
 switch_state_handler_table_t wanpipe_state_handlers = {
 	/*.on_init */ wanpipe_on_init,
-	/*.on_ring */ wanpipe_on_ring,
+	/*.on_routing */ wanpipe_on_routing,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ wanpipe_on_hangup,
-	/*.on_loopback */ wanpipe_on_loopback,
-	/*.on_transmit */ wanpipe_on_transmit
+	/*.on_exchange_media */ wanpipe_on_exchange_media,
+	/*.on_soft_execute */ wanpipe_on_soft_execute
 };
 
 static switch_call_cause_t wanpipe_outgoing_channel(switch_core_session_t *session, switch_caller_profile_t *outbound_profile,
@@ -1463,7 +1463,7 @@
 }
 
 
-static int on_ringing(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent)
+static int on_routinging(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent)
 {
 	switch_core_session_t *session;
 	switch_channel_t *channel;
@@ -1489,7 +1489,7 @@
 }
 
 
-static int on_ring(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent)
+static int on_routing(struct sangoma_pri *spri, sangoma_pri_event_t event_type, pri_event *pevent)
 {
 	char name[128];
 	switch_core_session_t *session = NULL;
@@ -1671,8 +1671,8 @@
 
 	switch_mutex_init(&chanmap.mutex, SWITCH_MUTEX_NESTED, module_pool);
 	SANGOMA_MAP_PRI_EVENT((*spri), SANGOMA_PRI_EVENT_ANY, on_anything);
-	SANGOMA_MAP_PRI_EVENT((*spri), SANGOMA_PRI_EVENT_RING, on_ring);
-	SANGOMA_MAP_PRI_EVENT((*spri), SANGOMA_PRI_EVENT_RINGING, on_ringing);
+	SANGOMA_MAP_PRI_EVENT((*spri), SANGOMA_PRI_EVENT_RING, on_routing);
+	SANGOMA_MAP_PRI_EVENT((*spri), SANGOMA_PRI_EVENT_RINGING, on_routinging);
 	//SANGOMA_MAP_PRI_EVENT((*spri), SANGOMA_PRI_EVENT_SETUP_ACK, on_proceed);
 	SANGOMA_MAP_PRI_EVENT((*spri), SANGOMA_PRI_EVENT_PROCEEDING, on_proceed);
 	SANGOMA_MAP_PRI_EVENT((*spri), SANGOMA_PRI_EVENT_ANSWER, on_answer);

Modified: freeswitch/trunk/src/mod/endpoints/mod_woomera/mod_woomera.c
==============================================================================
--- freeswitch/trunk/src/mod/endpoints/mod_woomera/mod_woomera.c	(original)
+++ freeswitch/trunk/src/mod/endpoints/mod_woomera/mod_woomera.c	Mon May  5 11:30:55 2008
@@ -170,9 +170,9 @@
 
 static switch_status_t woomera_on_init(switch_core_session_t *session);
 static switch_status_t woomera_on_hangup(switch_core_session_t *session);
-static switch_status_t woomera_on_ring(switch_core_session_t *session);
-static switch_status_t woomera_on_loopback(switch_core_session_t *session);
-static switch_status_t woomera_on_transmit(switch_core_session_t *session);
+static switch_status_t woomera_on_routing(switch_core_session_t *session);
+static switch_status_t woomera_on_exchange_media(switch_core_session_t *session);
+static switch_status_t woomera_on_soft_execute(switch_core_session_t *session);
 static switch_call_cause_t woomera_outgoing_channel(switch_core_session_t *session,
 													switch_caller_profile_t *outbound_profile,
 													switch_core_session_t **new_session, switch_memory_pool_t **pool, switch_originate_flag_t flags);
@@ -238,7 +238,7 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t woomera_on_ring(switch_core_session_t *session)
+static switch_status_t woomera_on_routing(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "%s WOOMERA RING\n", switch_channel_get_name(switch_core_session_get_channel(session)));
 	return SWITCH_STATUS_SUCCESS;
@@ -310,13 +310,13 @@
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t woomera_on_loopback(switch_core_session_t *session)
+static switch_status_t woomera_on_exchange_media(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "WOOMERA LOOPBACK\n");
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t woomera_on_transmit(switch_core_session_t *session)
+static switch_status_t woomera_on_soft_execute(switch_core_session_t *session)
 {
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "WOOMERA TRANSMIT\n");
 	return SWITCH_STATUS_SUCCESS;
@@ -405,11 +405,11 @@
 
 static switch_state_handler_table_t woomera_event_handlers = {
 	/*.on_init */ woomera_on_init,
-	/*.on_ring */ woomera_on_ring,
+	/*.on_routing */ woomera_on_routing,
 	/*.on_execute */ woomera_on_execute,
 	/*.on_hangup */ woomera_on_hangup,
-	/*.on_loopback */ woomera_on_loopback,
-	/*.on_transmit */ woomera_on_transmit
+	/*.on_exchange_media */ woomera_on_exchange_media,
+	/*.on_soft_execute */ woomera_on_soft_execute
 };
 
 static switch_io_routines_t woomera_io_routines = {
@@ -1044,7 +1044,7 @@
 					}
 					/* Move Channel's State Machine to RING */
 					switch_channel_answer(channel);
-					switch_channel_set_state(channel, CS_RING);
+					switch_channel_set_state(channel, CS_ROUTING);
 
 					if (switch_sockaddr_info_get(&tech_pvt->udpwrite,
 												 ip, SWITCH_UNSPEC, port, 0, switch_core_session_get_pool(tech_pvt->session)) != SWITCH_STATUS_SUCCESS) {

Modified: freeswitch/trunk/src/mod/event_handlers/mod_cdr_csv/mod_cdr_csv.c
==============================================================================
--- freeswitch/trunk/src/mod/event_handlers/mod_cdr_csv/mod_cdr_csv.c	(original)
+++ freeswitch/trunk/src/mod/event_handlers/mod_cdr_csv/mod_cdr_csv.c	Mon May  5 11:30:55 2008
@@ -255,11 +255,11 @@
 
 static switch_state_handler_table_t state_handlers = {
 	/*.on_init */ NULL,
-	/*.on_ring */ NULL,
+	/*.on_routing */ NULL,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ my_on_hangup,
-	/*.on_loopback */ NULL,
-	/*.on_transmit */ NULL
+	/*.on_exchange_media */ NULL,
+	/*.on_soft_execute */ NULL
 };
 
 

Modified: freeswitch/trunk/src/mod/event_handlers/mod_radius_cdr/mod_radius_cdr.c
==============================================================================
--- freeswitch/trunk/src/mod/event_handlers/mod_radius_cdr/mod_radius_cdr.c	(original)
+++ freeswitch/trunk/src/mod/event_handlers/mod_radius_cdr/mod_radius_cdr.c	Mon May  5 11:30:55 2008
@@ -130,7 +130,7 @@
 	return rad_config;
 }
 
-static switch_status_t my_on_ring(switch_core_session_t *session)
+static switch_status_t my_on_routing(switch_core_session_t *session)
 {
 	switch_xml_t 	cdr;
 	switch_channel_t *channel = switch_core_session_get_channel(session);
@@ -149,7 +149,7 @@
 	switch_time_exp_t tm;
 	char buffer[32];
 
-	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "[mod_radius_cdr] Entering my_on_ring\n");
+	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "[mod_radius_cdr] Entering my_on_routing\n");
 
 	rad_config = my_radius_init();
 
@@ -716,11 +716,11 @@
 
 static const switch_state_handler_table_t state_handlers = {
 	/*.on_init */ NULL,
-	/*.on_ring */ my_on_ring,
+	/*.on_routing */ my_on_routing,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ my_on_hangup,
-	/*.on_loopback */ NULL,
-	/*.on_transmit */ NULL
+	/*.on_exchange_media */ NULL,
+	/*.on_soft_execute */ NULL
 };
 
 SWITCH_MODULE_LOAD_FUNCTION(mod_radius_cdr_load)

Modified: freeswitch/trunk/src/mod/languages/mod_lua/freeswitch_lua.cpp
==============================================================================
--- freeswitch/trunk/src/mod/languages/mod_lua/freeswitch_lua.cpp	(original)
+++ freeswitch/trunk/src/mod/languages/mod_lua/freeswitch_lua.cpp	Mon May  5 11:30:55 2008
@@ -71,7 +71,7 @@
 
 void Session::check_hangup_hook() 
 {
-	if (hangup_func_str && (hook_state == CS_HANGUP || hook_state == CS_RING)) {
+	if (hangup_func_str && (hook_state == CS_HANGUP || hook_state == CS_ROUTING)) {
 		hh++;
 	}
 }

Modified: freeswitch/trunk/src/mod/languages/mod_perl/freeswitch_perl.cpp
==============================================================================
--- freeswitch/trunk/src/mod/languages/mod_perl/freeswitch_perl.cpp	(original)
+++ freeswitch/trunk/src/mod/languages/mod_perl/freeswitch_perl.cpp	Mon May  5 11:30:55 2008
@@ -67,7 +67,7 @@
 
 void Session::check_hangup_hook() 
 {
-	if (hangup_func_str && (hook_state == CS_HANGUP || hook_state == CS_RING)) {
+	if (hangup_func_str && (hook_state == CS_HANGUP || hook_state == CS_ROUTING)) {
 		hh++;
 	}
 }

Modified: freeswitch/trunk/src/mod/languages/mod_python/switch_swig_wrap.c
==============================================================================
--- freeswitch/trunk/src/mod/languages/mod_python/switch_swig_wrap.c	(original)
+++ freeswitch/trunk/src/mod/languages/mod_python/switch_swig_wrap.c	Mon May  5 11:30:55 2008
@@ -2924,19 +2924,19 @@
 		PyDict_SetItemString(d, "CS_INIT", SWIG_From_int((int) (CS_INIT)));
 	}
 	{
-		PyDict_SetItemString(d, "CS_RING", SWIG_From_int((int) (CS_RING)));
+		PyDict_SetItemString(d, "CS_ROUTING", SWIG_From_int((int) (CS_ROUTING)));
 	}
 	{
-		PyDict_SetItemString(d, "CS_TRANSMIT", SWIG_From_int((int) (CS_TRANSMIT)));
+		PyDict_SetItemString(d, "CS_SOFT_EXECUTE", SWIG_From_int((int) (CS_SOFT_EXECUTE)));
 	}
 	{
 		PyDict_SetItemString(d, "CS_EXECUTE", SWIG_From_int((int) (CS_EXECUTE)));
 	}
 	{
-		PyDict_SetItemString(d, "CS_LOOPBACK", SWIG_From_int((int) (CS_LOOPBACK)));
+		PyDict_SetItemString(d, "CS_EXCHANGE_MEDIA", SWIG_From_int((int) (CS_EXCHANGE_MEDIA)));
 	}
 	{
-		PyDict_SetItemString(d, "CS_HOLD", SWIG_From_int((int) (CS_HOLD)));
+		PyDict_SetItemString(d, "CS_CONSUME_MEDIA", SWIG_From_int((int) (CS_CONSUME_MEDIA)));
 	}
 	{
 		PyDict_SetItemString(d, "CS_HIBERNATE", SWIG_From_int((int) (CS_HIBERNATE)));

Modified: freeswitch/trunk/src/mod/languages/mod_spidermonkey/mod_spidermonkey.c
==============================================================================
--- freeswitch/trunk/src/mod/languages/mod_spidermonkey/mod_spidermonkey.c	(original)
+++ freeswitch/trunk/src/mod/languages/mod_spidermonkey/mod_spidermonkey.c	Mon May  5 11:30:55 2008
@@ -1560,7 +1560,7 @@
 	int argc = 0;
 	jsval ret;
 
-	if (jss->on_hangup && (jss->hook_state == CS_HANGUP || jss->hook_state == CS_RING)) {
+	if (jss->on_hangup && (jss->hook_state == CS_HANGUP || jss->hook_state == CS_ROUTING)) {
 		argv[argc++] = OBJECT_TO_JSVAL(jss->obj);
 		if (jss->hook_state == CS_HANGUP) {
 			argv[argc++] = STRING_TO_JSVAL(JS_NewStringCopyZ(jss->cx, "hangup"));
@@ -2754,7 +2754,7 @@
 		jss->session = peer_session;
 		switch_set_flag(jss, S_HUP);
 		*rval = BOOLEAN_TO_JSVAL(JS_TRUE);
-		switch_channel_set_state(switch_core_session_get_channel(jss->session), CS_TRANSMIT);
+		switch_channel_set_state(switch_core_session_get_channel(jss->session), CS_SOFT_EXECUTE);
 
 	} else {
 		switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_WARNING, "Missing Args\n");

Modified: freeswitch/trunk/src/mod/xml_int/mod_xml_cdr/mod_xml_cdr.c
==============================================================================
--- freeswitch/trunk/src/mod/xml_int/mod_xml_cdr/mod_xml_cdr.c	(original)
+++ freeswitch/trunk/src/mod/xml_int/mod_xml_cdr/mod_xml_cdr.c	Mon May  5 11:30:55 2008
@@ -241,11 +241,11 @@
 
 static switch_state_handler_table_t state_handlers = {
 	/*.on_init */ NULL,
-	/*.on_ring */ NULL,
+	/*.on_routing */ NULL,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ my_on_hangup,
-	/*.on_loopback */ NULL,
-	/*.on_transmit */ NULL
+	/*.on_exchange_media */ NULL,
+	/*.on_soft_execute */ NULL
 };
 
 SWITCH_MODULE_LOAD_FUNCTION(mod_xml_cdr_load)

Modified: freeswitch/trunk/src/switch_channel.c
==============================================================================
--- freeswitch/trunk/src/switch_channel.c	(original)
+++ freeswitch/trunk/src/switch_channel.c	Mon May  5 11:30:55 2008
@@ -721,7 +721,7 @@
 
 	switch_assert(channel != NULL);
 
-	if (!channel->hangup_cause && channel->state > CS_RING && channel->state < CS_HANGUP && channel->state != CS_RESET && 
+	if (!channel->hangup_cause && channel->state > CS_ROUTING && channel->state < CS_HANGUP && channel->state != CS_RESET && 
 		!switch_test_flag(channel, CF_TRANSFER)) {
 			ret++;
 	}
@@ -732,12 +732,12 @@
 static const char *state_names[] = {
 	"CS_NEW",
 	"CS_INIT",
-	"CS_RING",
-	"CS_TRANSMIT",
+	"CS_ROUTING",
+	"CS_SOFT_EXECUTE",
 	"CS_EXECUTE",
-	"CS_LOOPBACK",
+	"CS_EXCHANGE_MEDIA",
 	"CS_PARK",
-	"CS_HOLD",
+	"CS_CONSUME_MEDIA",
 	"CS_HIBERNATE",
 	"CS_RESET",
 	"CS_HANGUP",
@@ -776,7 +776,7 @@
 		channel->state_flags = 0;
 	}
 
-	if (channel->state >= CS_RING) {
+	if (channel->state >= CS_ROUTING) {
 		switch_clear_flag(channel, CF_TRANSFER);
 		switch_channel_presence(channel, "unknown", (char *) state_names[state]);
 	}
@@ -784,7 +784,7 @@
 	if (state < CS_HANGUP) {
 		switch_event_t *event;
 		if (switch_event_create(&event, SWITCH_EVENT_CHANNEL_STATE) == SWITCH_STATUS_SUCCESS) {
-			if (state == CS_RING) {
+			if (state == CS_ROUTING) {
 				switch_channel_event_set_data(channel, event);
 			} else {
 				char state_num[25];
@@ -838,9 +838,9 @@
 
 	case CS_NEW:
 	case CS_INIT:
-	case CS_LOOPBACK:
-	case CS_TRANSMIT:
-	case CS_RING:
+	case CS_EXCHANGE_MEDIA:
+	case CS_SOFT_EXECUTE:
+	case CS_ROUTING:
 	case CS_EXECUTE:
 	case CS_HANGUP:
 	case CS_DONE:
@@ -863,12 +863,12 @@
 
 case CS_INIT:
 	switch (state) {
-case CS_LOOPBACK:
-case CS_TRANSMIT:
-case CS_RING:
+case CS_EXCHANGE_MEDIA:
+case CS_SOFT_EXECUTE:
+case CS_ROUTING:
 case CS_EXECUTE:
 case CS_PARK:
-case CS_HOLD:
+case CS_CONSUME_MEDIA:
 case CS_HIBERNATE:
 case CS_RESET:
 	ok++;
@@ -877,13 +877,13 @@
 	}
 	break;
 
-case CS_LOOPBACK:
+case CS_EXCHANGE_MEDIA:
 	switch (state) {
-case CS_TRANSMIT:
-case CS_RING:
+case CS_SOFT_EXECUTE:
+case CS_ROUTING:
 case CS_EXECUTE:
 case CS_PARK:
-case CS_HOLD:
+case CS_CONSUME_MEDIA:
 case CS_HIBERNATE:
 case CS_RESET:
 	ok++;
@@ -892,13 +892,13 @@
 	}
 	break;
 
-case CS_TRANSMIT:
+case CS_SOFT_EXECUTE:
 	switch (state) {
-case CS_LOOPBACK:
-case CS_RING:
+case CS_EXCHANGE_MEDIA:
+case CS_ROUTING:
 case CS_EXECUTE:
 case CS_PARK:
-case CS_HOLD:
+case CS_CONSUME_MEDIA:
 case CS_HIBERNATE:
 case CS_RESET:
 	ok++;
@@ -909,25 +909,25 @@
 
 case CS_PARK:
 	switch (state) {
-case CS_LOOPBACK:
-case CS_RING:
+case CS_EXCHANGE_MEDIA:
+case CS_ROUTING:
 case CS_EXECUTE:
-case CS_TRANSMIT:
+case CS_SOFT_EXECUTE:
 case CS_HIBERNATE:
 case CS_RESET:
-case CS_HOLD:
+case CS_CONSUME_MEDIA:
 	ok++;
 default:
 	break;
 	}
 	break;
 
-case CS_HOLD:
+case CS_CONSUME_MEDIA:
 	switch (state) {
-case CS_LOOPBACK:
-case CS_RING:
+case CS_EXCHANGE_MEDIA:
+case CS_ROUTING:
 case CS_EXECUTE:
-case CS_TRANSMIT:
+case CS_SOFT_EXECUTE:
 case CS_HIBERNATE:
 case CS_RESET:
 case CS_PARK:
@@ -938,13 +938,13 @@
 	break;
 case CS_HIBERNATE:
 	switch (state) {
-case CS_LOOPBACK:
+case CS_EXCHANGE_MEDIA:
 case CS_INIT:
-case CS_RING:
+case CS_ROUTING:
 case CS_EXECUTE:
-case CS_TRANSMIT:
+case CS_SOFT_EXECUTE:
 case CS_PARK:
-case CS_HOLD:
+case CS_CONSUME_MEDIA:
 case CS_RESET:
 	ok++;
 default:
@@ -952,13 +952,13 @@
 	}
 	break;
 
-case CS_RING:
+case CS_ROUTING:
 	switch (state) {
-case CS_LOOPBACK:
+case CS_EXCHANGE_MEDIA:
 case CS_EXECUTE:
-case CS_TRANSMIT:
+case CS_SOFT_EXECUTE:
 case CS_PARK:
-case CS_HOLD:
+case CS_CONSUME_MEDIA:
 case CS_HIBERNATE:
 case CS_RESET:
 	ok++;
@@ -969,11 +969,11 @@
 
 case CS_EXECUTE:
 	switch (state) {
-case CS_LOOPBACK:
-case CS_TRANSMIT:
-case CS_RING:
+case CS_EXCHANGE_MEDIA:
+case CS_SOFT_EXECUTE:
+case CS_ROUTING:
 case CS_PARK:
-case CS_HOLD:
+case CS_CONSUME_MEDIA:
 case CS_HIBERNATE:
 case CS_RESET:
 	ok++;

Modified: freeswitch/trunk/src/switch_core_sqldb.c
==============================================================================
--- freeswitch/trunk/src/switch_core_sqldb.c	(original)
+++ freeswitch/trunk/src/switch_core_sqldb.c	Mon May  5 11:30:55 2008
@@ -287,7 +287,7 @@
 			case CS_HANGUP:
 			case CS_DONE:
 				break;
-			case CS_RING:
+			case CS_ROUTING:
 				sql = switch_mprintf("update channels set state='%s',cid_name='%q',cid_num='%q',ip_addr='%s',dest='%q' "
 									 "where uuid='%s'",
 									 switch_event_get_header(event, "channel-state"),

Modified: freeswitch/trunk/src/switch_core_state_machine.c
==============================================================================
--- freeswitch/trunk/src/switch_core_state_machine.c	(original)
+++ freeswitch/trunk/src/switch_core_state_machine.c	Mon May  5 11:30:55 2008
@@ -54,7 +54,7 @@
 					  switch_channel_get_name(session->channel));	
 }
 
-static void switch_core_standard_on_ring(switch_core_session_t *session)
+static void switch_core_standard_on_routing(switch_core_session_t *session)
 {
 	switch_dialplan_interface_t *dialplan_interface = NULL;
 	switch_caller_profile_t *caller_profile;
@@ -103,7 +103,7 @@
 		if (!count) {
 			if (switch_channel_test_flag(session->channel, CF_OUTBOUND)) {
 				switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_INFO, "No Dialplan, changing state to HOLD\n");
-				switch_channel_set_state(session->channel, CS_HOLD);
+				switch_channel_set_state(session->channel, CS_CONSUME_MEDIA);
 				goto end;
 			}
 		}
@@ -157,14 +157,14 @@
 	}
 }
 
-static void switch_core_standard_on_loopback(switch_core_session_t *session)
+static void switch_core_standard_on_exchange_media(switch_core_session_t *session)
 {
 
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "Standard LOOPBACK\n");
 	switch_ivr_session_echo(session);
 }
 
-static void switch_core_standard_on_transmit(switch_core_session_t *session)
+static void switch_core_standard_on_soft_execute(switch_core_session_t *session)
 {
 	switch_assert(session != NULL);
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "Standard TRANSMIT\n");
@@ -179,7 +179,7 @@
 	switch_ivr_park(session, NULL);
 }
 
-static void switch_core_standard_on_hold(switch_core_session_t *session)
+static void switch_core_standard_on_consume_media(switch_core_session_t *session)
 {
 	switch_assert(session != NULL);
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "Standard HOLD\n");
@@ -413,9 +413,9 @@
 				STATE_MACRO(init, "INIT");
 				switch_core_session_signal_unlock(session);
 				break;
-			case CS_RING: /* Look for a dialplan and find something to do */
+			case CS_ROUTING: /* Look for a dialplan and find something to do */
 				switch_core_session_signal_lock(session);
-				STATE_MACRO(ring, "RING");
+				STATE_MACRO(routing, "ROUTING");
 				switch_core_session_signal_unlock(session);
 				break;
 			case CS_RESET: /* Reset */
@@ -427,17 +427,17 @@
 			case CS_EXECUTE: /* Execute an Operation */
 				STATE_MACRO(execute, "EXECUTE");
 				break;
-			case CS_LOOPBACK: /* loop all data back to source */
-				STATE_MACRO(loopback, "LOOPBACK");
+			case CS_EXCHANGE_MEDIA: /* loop all data back to source */
+				STATE_MACRO(exchange_media, "EXCHANGE_MEDIA");
 				break;
-			case CS_TRANSMIT: /* send/recieve data to/from another channel */
-				STATE_MACRO(transmit, "TRANSMIT");
+			case CS_SOFT_EXECUTE: /* send/recieve data to/from another channel */
+				STATE_MACRO(soft_execute, "SOFT_EXECUTE");
 				break;
 			case CS_PARK: /* wait in limbo */
 				STATE_MACRO(park, "PARK");
 				break;
-			case CS_HOLD: /* wait in limbo */
-				STATE_MACRO(hold, "HOLD");
+			case CS_CONSUME_MEDIA: /* wait in limbo */
+				STATE_MACRO(consume_media, "CONSUME_MEDIA");
 				break;
 			case CS_HIBERNATE: /* sleep */
 				STATE_MACRO(hibernate, "HIBERNATE");

Modified: freeswitch/trunk/src/switch_cpp.cpp
==============================================================================
--- freeswitch/trunk/src/switch_cpp.cpp	(original)
+++ freeswitch/trunk/src/switch_cpp.cpp	Mon May  5 11:30:55 2008
@@ -352,7 +352,7 @@
 			allocated = 1;
 			switch_set_flag(this, S_HUP);
 			uuid = strdup(switch_core_session_get_uuid(session));
-			switch_channel_set_state(switch_core_session_get_channel(session), CS_TRANSMIT);
+			switch_channel_set_state(switch_core_session_get_channel(session), CS_SOFT_EXECUTE);
 		}
 	}
 }
@@ -694,7 +694,7 @@
     if (a_leg_session) a_leg_session->end_allow_threads();
 	channel = switch_core_session_get_channel(session);
 	allocated = 1;
-	switch_channel_set_state(switch_core_session_get_channel(session), CS_TRANSMIT);
+	switch_channel_set_state(switch_core_session_get_channel(session), CS_SOFT_EXECUTE);
 
 	return SWITCH_STATUS_SUCCESS;
 

Modified: freeswitch/trunk/src/switch_ivr.c
==============================================================================
--- freeswitch/trunk/src/switch_ivr.c	(original)
+++ freeswitch/trunk/src/switch_ivr.c	Mon May  5 11:30:55 2008
@@ -1023,7 +1023,7 @@
 		switch_channel_set_caller_profile(channel, new_profile);
 		switch_channel_set_flag(channel, CF_TRANSFER);
 
-		switch_channel_set_state(channel, CS_RING);
+		switch_channel_set_state(channel, CS_ROUTING);
 		
 		msg.message_id = SWITCH_MESSAGE_INDICATE_TRANSFER;
 		msg.from = __FILE__;

Modified: freeswitch/trunk/src/switch_ivr_bridge.c
==============================================================================
--- freeswitch/trunk/src/switch_ivr_originate.c	(original)
+++ freeswitch/trunk/src/switch_ivr_originate.c	Mon May  5 11:30:55 2008
@@ -34,11 +34,11 @@
 
 static const switch_state_handler_table_t originate_state_handlers;
 
-static switch_status_t originate_on_hold_transmit(switch_core_session_t *session)
+static switch_status_t originate_on_consume_media_transmit(switch_core_session_t *session)
 {
 	switch_channel_t *channel = switch_core_session_get_channel(session);
 	
-	while(switch_channel_get_state(channel) == CS_HOLD) {
+	while(switch_channel_get_state(channel) == CS_CONSUME_MEDIA) {
 		switch_ivr_sleep(session, 10);
 	}
 	
@@ -47,24 +47,24 @@
 	return SWITCH_STATUS_FALSE;
 }
 
-static switch_status_t originate_on_ring(switch_core_session_t *session)
+static switch_status_t originate_on_routing(switch_core_session_t *session)
 {
 	switch_channel_t *channel = switch_core_session_get_channel(session);
 
 	/* put the channel in a passive state until it is answered */
-	switch_channel_set_state(channel, CS_HOLD);
+	switch_channel_set_state(channel, CS_CONSUME_MEDIA);
 
 	return SWITCH_STATUS_FALSE;
 }
 
 static const switch_state_handler_table_t originate_state_handlers = {
 	/*.on_init */ NULL,
-	/*.on_ring */ originate_on_ring,
+	/*.on_routing */ originate_on_routing,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ NULL,
-	/*.on_loopback */ NULL,
-	/*.on_transmit */ originate_on_hold_transmit,
-	/*.on_hold */ originate_on_hold_transmit
+	/*.on_exchange_media */ NULL,
+	/*.on_soft_execute */ originate_on_consume_media_transmit,
+	/*.on_consume_media */ originate_on_consume_media_transmit
 };
 
 typedef enum {
@@ -113,7 +113,7 @@
 			goto wbreak;
 		}
 
-		switch_channel_set_state(channel, CS_TRANSMIT);
+		switch_channel_set_state(channel, CS_SOFT_EXECUTE);
 		switch_core_session_exec(collect->session, application_interface, app_data);
 		
 		if (switch_channel_get_state(channel) < CS_HANGUP) {
@@ -884,7 +884,7 @@
 				
 				if (!switch_core_session_running(peer_sessions[i])) {
 					//if (!(flags & SOF_NOBLOCK)) {
-                    //switch_channel_set_state(peer_channels[i], CS_RING);
+                    //switch_channel_set_state(peer_channels[i], CS_ROUTING);
 					//}
                     //} else {
 					switch_core_session_thread_launch(peer_sessions[i]);
@@ -910,7 +910,7 @@
 						continue;
 					}
 
-					if (state >= CS_RING) {
+					if (state >= CS_ROUTING) {
 						goto endfor1;
 					}
 



More information about the Freeswitch-svn mailing list
--- freeswitch/trunk/src/switch_ivr_bridge.c	(original)
+++ freeswitch/trunk/src/switch_ivr_bridge.c	Mon May  5 11:30:55 2008
@@ -354,7 +354,7 @@
 	return NULL;
 }
 
-static switch_status_t audio_bridge_on_loopback(switch_core_session_t *session)
+static switch_status_t audio_bridge_on_exchange_media(switch_core_session_t *session)
 {
 	switch_channel_t *channel = switch_core_session_get_channel(session);
 	switch_ivr_bridge_data_t *bd = switch_channel_get_private(channel, "_bridge_");
@@ -374,25 +374,25 @@
 
 	state = switch_channel_get_state(channel);
 
-	if (!switch_channel_test_flag(channel, CF_TRANSFER) && state != CS_PARK && state != CS_RING) {
+	if (!switch_channel_test_flag(channel, CF_TRANSFER) && state != CS_PARK && state != CS_ROUTING) {
 		switch_channel_hangup(channel, SWITCH_CAUSE_NORMAL_CLEARING);
 	}
 
 	return SWITCH_STATUS_FALSE;
 }
 
-static switch_status_t audio_bridge_on_ring(switch_core_session_t *session)
+static switch_status_t audio_bridge_on_routing(switch_core_session_t *session)
 {
 	switch_channel_t *channel = switch_core_session_get_channel(session);
 
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "%s CUSTOM RING\n", switch_channel_get_name(channel));
 
 	/* put the channel in a passive state so we can loop audio to it */
-	switch_channel_set_state(channel, CS_HOLD);
+	switch_channel_set_state(channel, CS_CONSUME_MEDIA);
 	return SWITCH_STATUS_FALSE;
 }
 
-static switch_status_t audio_bridge_on_hold(switch_core_session_t *session)
+static switch_status_t audio_bridge_on_consume_media(switch_core_session_t *session)
 {
 	switch_channel_t *channel = switch_core_session_get_channel(session);
 
@@ -404,12 +404,12 @@
 
 static const switch_state_handler_table_t audio_bridge_peer_state_handlers = {
 	/*.on_init */ NULL,
-	/*.on_ring */ audio_bridge_on_ring,
+	/*.on_routing */ audio_bridge_on_routing,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ NULL,
-	/*.on_loopback */ audio_bridge_on_loopback,
-	/*.on_transmit */ NULL,
-	/*.on_hold */ audio_bridge_on_hold,
+	/*.on_exchange_media */ audio_bridge_on_exchange_media,
+	/*.on_soft_execute */ NULL,
+	/*.on_consume_media */ audio_bridge_on_consume_media,
 };
 
 static switch_status_t uuid_bridge_on_reset(switch_core_session_t *session)
@@ -421,13 +421,13 @@
 	switch_channel_clear_flag(channel, CF_TRANSFER);
 
 	if (switch_channel_test_flag(channel, CF_ORIGINATOR)) {
-		switch_channel_set_state(channel, CS_TRANSMIT);
+		switch_channel_set_state(channel, CS_SOFT_EXECUTE);
 	}
 
 	return SWITCH_STATUS_SUCCESS;
 }
 
-static switch_status_t uuid_bridge_on_transmit(switch_core_session_t *session)
+static switch_status_t uuid_bridge_on_soft_execute(switch_core_session_t *session)
 {
 	switch_channel_t *channel = switch_core_session_get_channel(session);
 	switch_core_session_t *other_session;
@@ -459,10 +459,10 @@
 		}
 
 		if (switch_channel_get_state(other_channel) == CS_RESET) {
-			switch_channel_set_state(other_channel, CS_TRANSMIT);
+			switch_channel_set_state(other_channel, CS_SOFT_EXECUTE);
 		}
 
-		switch_channel_wait_for_state(channel, other_channel, CS_TRANSMIT);
+		switch_channel_wait_for_state(channel, other_channel, CS_SOFT_EXECUTE);
 
 		switch_channel_clear_flag(channel, CF_TRANSFER);
 		switch_channel_clear_flag(other_channel, CF_TRANSFER);
@@ -512,12 +512,12 @@
 
 static const switch_state_handler_table_t uuid_bridge_state_handlers = {
 	/*.on_init */ NULL,
-	/*.on_ring */ NULL,
+	/*.on_routing */ NULL,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ NULL,
-	/*.on_loopback */ NULL,
-	/*.on_transmit */ uuid_bridge_on_transmit,
-	/*.on_hold */ NULL,
+	/*.on_exchange_media */ NULL,
+	/*.on_soft_execute */ uuid_bridge_on_soft_execute,
+	/*.on_consume_media */ NULL,
 	/*.on_hibernate*/ NULL,
 	/*.on_reset*/ uuid_bridge_on_reset
 };
@@ -572,12 +572,12 @@
 
 static const switch_state_handler_table_t signal_bridge_state_handlers = {
 	/*.on_init */ NULL,
-	/*.on_ring */ NULL,
+	/*.on_routing */ NULL,
 	/*.on_execute */ NULL,
 	/*.on_hangup */ signal_bridge_on_hangup,
-	/*.on_loopback */ NULL,
-	/*.on_transmit */ NULL,
-	/*.on_hold */ NULL,
+	/*.on_exchange_media */ NULL,
+	/*.on_soft_execute */ NULL,
+	/*.on_consume_media */ NULL,
 	/*.on_hibernate */ signal_bridge_on_hibernate
 };
 
@@ -681,7 +681,7 @@
 		const switch_application_interface_t *application_interface;
 		const char *app, *data;
 
-		switch_channel_set_state(peer_channel, CS_HOLD);
+		switch_channel_set_state(peer_channel, CS_CONSUME_MEDIA);
 
 		if (switch_event_create(&event, SWITCH_EVENT_CHANNEL_BRIDGE) == SWITCH_STATUS_SUCCESS) {
 			switch_channel_event_set_data(caller_channel, event);
@@ -697,7 +697,7 @@
 				if ((status = switch_ivr_wait_for_answer(session, peer_session)) != SWITCH_STATUS_SUCCESS) {
 					switch_channel_state_t w_state = switch_channel_get_state(caller_channel);
 					switch_channel_hangup(peer_channel, SWITCH_CAUSE_ALLOTTED_TIMEOUT);
-					if (w_state < CS_HANGUP && w_state != CS_RING && w_state != CS_PARK && !switch_channel_test_flag(caller_channel, CF_TRANSFER) &&
+					if (w_state < CS_HANGUP && w_state != CS_ROUTING && w_state != CS_PARK && !switch_channel_test_flag(caller_channel, CF_TRANSFER) &&
 						w_state != CS_EXECUTE) {
 						const char *ext = switch_channel_get_variable(peer_channel, "original_destination_number");
 						if (!ext) {
@@ -757,17 +757,17 @@
 			}
 
 			switch_channel_set_private(peer_channel, "_bridge_", b_leg);
-			switch_channel_set_state(peer_channel, CS_LOOPBACK);
+			switch_channel_set_state(peer_channel, CS_EXCHANGE_MEDIA);
 			audio_bridge_thread(NULL, (void *) a_leg);
 
 			switch_channel_clear_flag(caller_channel, CF_ORIGINATOR);
 			//make sure this doesnt break anything
 
-			if (!switch_channel_test_flag(peer_channel, CF_TRANSFER) && switch_channel_get_state(peer_channel) == CS_LOOPBACK) {
+			if (!switch_channel_test_flag(peer_channel, CF_TRANSFER) && switch_channel_get_state(peer_channel) == CS_EXCHANGE_MEDIA) {
 				switch_channel_set_state(peer_channel, CS_RESET);
 			}
 
-			while (switch_channel_get_state(peer_channel) == CS_LOOPBACK) {
+			while (switch_channel_get_state(peer_channel) == CS_EXCHANGE_MEDIA) {
 				switch_yield(1000);
 			}
 
@@ -800,7 +800,7 @@
 	state = switch_channel_get_state(caller_channel);
 	
 	if (!switch_channel_test_flag(caller_channel, CF_TRANSFER)) {
-		if ((state != CS_EXECUTE && state != CS_PARK && state != CS_RING) || 
+		if ((state != CS_EXECUTE && state != CS_PARK && state != CS_ROUTING) || 
 			(switch_channel_test_flag(peer_channel, CF_ANSWERED) && state < CS_HANGUP && 
 			 switch_true(switch_channel_get_variable(caller_channel, SWITCH_HANGUP_AFTER_BRIDGE_VARIABLE)))) {
 			switch_channel_hangup(caller_channel, switch_channel_get_cause(peer_channel));
@@ -849,7 +849,7 @@
 
 			/* override transmit state for originator_channel to bridge to originatee_channel 
 			 * install pointer to originatee_session into originator_channel
 			 * set CF_TRANSFER on both channels and change state to CS_TRANSMIT to
 			 * inturrupt anything they are already doing.
 			 * originatee_session will fall asleep and originator_session will bridge to it
 			 */
@@ -849,7 +849,7 @@
 			/* override transmit state for originator_channel to bridge to originatee_channel 
 			 * install pointer to originatee_session into originator_channel
-			 * set CF_TRANSFER on both channels and change state to CS_TRANSMIT to
+			 * set CF_TRANSFER on both channels and change state to CS_SOFT_EXECUTE to
 			 * inturrupt anything they are already doing.
 			 * originatee_session will fall asleep and originator_session will bridge to it

Modified: freeswitch/trunk/src/switch_ivr_originate.c
==============================================================================